@@ -32,6 +32,10 @@
 
 #include "HPCupsFilter.h"
 
+#ifndef DISABLE_IMAGEPROCESSOR
+#include "ImageProcessor.h"
+#endif
+
 #include <signal.h>
 #include <sys/wait.h>
 #include <sys/utsname.h>
@@ -282,6 +286,7 @@ DRIVER_ERROR HPCupsFilter::startPage (cups_page_header2_t *cups_header)
     }
 
     m_JA.quality_attributes.media_type = cups_header->cupsMediaType;
+    m_JA.quality_attributes.media_subtype = cups_header->cupsInteger[6];
     m_JA.quality_attributes.print_quality = atoi(cups_header->OutputType);
     m_JA.quality_attributes.horizontal_resolution = cups_header->HWResolution[0];
     m_JA.quality_attributes.vertical_resolution   = cups_header->HWResolution[1];
@@ -333,7 +338,16 @@ DRIVER_ERROR HPCupsFilter::startPage (cups_page_header2_t *cups_header)
 
     int    horz_res = cups_header->HWResolution[0];
     int    vert_res = cups_header->HWResolution[1];
-    m_JA.media_attributes.pcl_id = cups_header->cupsInteger[0];
+    //  Custom Page size should have cupsInteger0 set as 101 instead of 0
+    if(strncmp(cups_header->cupsPageSizeName, "Custom",6) == 0)
+    {
+	m_JA.media_attributes.pcl_id = 101;    
+    }
+    else
+    {
+        m_JA.media_attributes.pcl_id = cups_header->cupsInteger[0];
+    }	    
+
     m_JA.media_attributes.printable_start_x = (cups_header->Margins[0] * horz_res) / 72;
     m_JA.media_attributes.printable_start_y = ((cups_header->PageSize[1] - cups_header->ImagingBoundingBox[3]) * vert_res) / 72;
     m_JA.media_attributes.horizontal_overspray = (xoverspray * horz_res) / 1000;
@@ -656,8 +670,26 @@ int HPCupsFilter::processRasterData(cups_raster_t *cups_raster)
 
 
     sprintf(hpPreProcessedRasterFile, "%s/hp_%s_cups_SwapedPagesXXXXXX",CUPS_TMP_DIR, m_JA.user_name);
+    #ifndef DISABLE_IMAGEPROCESSOR 
+	    image_processor_t* imageProcessor=NULL;
+	    IMAGE_PROCESSOR_ERROR result;
+	    //added if condition to check if pinter language is "ljzjstream"
+	    //If so, then bypass imageprocessing functions while running HPCUPS filter.
+	    
+	    if(strncmp(m_JA.printer_platform, "ljzjstream",10) == 0){
+		imageProcessor = imageProcessorCreate();
+	    }
+    #endif
     while (cupsRasterReadHeader2(cups_raster, &cups_header))
     {
+       #ifndef DISABLE_IMAGEPROCESSOR 
+		   if(strncmp(m_JA.printer_platform, "ljzjstream",10) == 0){
+		    result = imageProcessorStartPage(imageProcessor, &cups_header);
+		    if (result != IPE_SUCCESS){
+		        dbglog("DEBUG: imageProcessorStartPage failed result = %d\n", result);
+		    }
+		    }
+       #endif
         current_page_number++;
 
         if (current_page_number == 1) {
@@ -755,7 +787,15 @@ int HPCupsFilter::processRasterData(cups_raster_t *cups_raster)
             cupsRasterReadPixels (cups_raster, m_pPrinterBuffer, cups_header.cupsBytesPerLine);
             color_raster = rgbRaster;
             black_raster = kRaster;
-
+            #ifndef DISABLE_IMAGEPROCESSOR 
+				if(strncmp(m_JA.printer_platform, "ljzjstream",10) == 0)
+				{
+						result = imageProcessorProcessLine(imageProcessor, m_pPrinterBuffer, cups_header.cupsBytesPerLine);
+						if (result != IPE_SUCCESS){
+						    dbglog("DEBUG: imageProcessorProcessLine failed result = %d\n", result);
+						}
+				}
+            #endif
             if ((y == 0) && !is_ljmono) {
                 //For ljmono, make sure that first line is not a blankRaster line.Otherwise printer
                 //may not skip blank lines before actual data
@@ -784,7 +824,15 @@ int HPCupsFilter::processRasterData(cups_raster_t *cups_raster)
                 WriteBMPRaster (kfp, black_raster, cups_header.cupsWidth/8, BLACK_RASTER);
             }
         }  // for() loop end
-
+		#ifndef DISABLE_IMAGEPROCESSOR 
+			if(strncmp(m_JA.printer_platform, "ljzjstream",10) == 0)
+			{
+				result = imageProcessorEndPage(imageProcessor);
+				if (result != IPE_SUCCESS){
+				        dbglog("DEBUG: imageProcessorEndPage failed result = %d\n", result);
+				}
+			}
+		#endif
         m_Job.NewPage();
         if (err != NO_ERROR) {
             break;
@@ -799,6 +847,13 @@ int HPCupsFilter::processRasterData(cups_raster_t *cups_raster)
         rgbRaster = NULL;
     }
 
+   #ifndef DISABLE_IMAGEPROCESSOR
+	   if(strncmp(m_JA.printer_platform, "ljzjstream",10) == 0)
+	   {
+		imageProcessorDestroy(imageProcessor);
+	   }
+   #endif
+
     unlink(hpPreProcessedRasterFile);
     return ret_status;
 }
